# Generated by Django 4.2.24 on 2026-03-17 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aws', '0005_alter_emaildomain_region_delete_s3bucket'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emaildomain',
            name='region',
            field=models.CharField(default=None, help_text='AWS region for SES operations', max_length=64),
        ),
    ]
